@@ -79,58 +79,58 @@ def info3():
 def info4():
     print("t1 'Работа с числами с плавающей точкой'")
     print("t2 'Архитектура памяти'")
-    print("t3 'Переполнение, потеря точности (overflow, underflow)'")
-    print("t4 'Ошибка округления, накопление ошибок, потеря значимости'")
+    print("t3 'Переполнение (overflow), потеря точности (underflow)'")
+    print("t4 'Ошибка округления в арифметике с плавающей точкой, накопление ошибок округления, потеря значимости'")
     print("t5 'Суммирование по Кахану'")
     print("t6 'Абсолютная и относительная погрешности'")
-    print("t7 'Округление и значащие цифры'")
-    print("t8 'Верные в узком и широком смысле цифры числа'")
-    print("t9 'Сложность алгоритмов, нотация O-большое'")
+    print("t7 'Округление и значащие цифры в записи приближенного числа'")
+    print("t8 'Верные в строгом (узком) смысле цифры числа, верные в широком смысле цифры числа'")
+    print("t9 'Сложность алгоритмов и нотация big-O'")
     print("t10 'Профилирование кода в Python'")
-    print("t11 'Стандарт IEEE 754 и ошибки представления чисел'")
+    print("t11 'Представление чисел с плавающей точкой (стандарт IEEE 754), ошибки представления'")
 
 def info5():
-    print("t12 'Изолирование корней нелинейных функций'")
+    print("t12 'Способы изолирования корней нелинейных функций'")
     print("t13 'Сжимающие отображения'")
-    print("t14 'Погрешность, критерии сходимости, константа Липшица'")
+    print("t14 'Погрешность и критерии сходимости, константа Липшица'")
     print("t15 'Скорость сходимости итерационного метода'")
-    print("t16 'Стабильность и распространение ошибок при решении нелинейных уравнений'")
+    print("t16 'Стабильность и распространение ошибки в методах численного решения нелинейных уравнений'")
     print("t17 'Теория сжимающих отображений'")
     print("t18 'Интерполяция, экстраполяция, аппроксимация'")
     print("t19 'Глобальная и локальная интерполяция'")
     print("t20 'Ступенчатая и линейная интерполяция'")
-    print("t21 'Интерполяционные полиномы и квадратичная интерполяция'")
+    print("t21 'Интерполяционные полиномы'")
 
 def info6():
-    print("t22 'Интерполяция сплайнами'")
-    print("t23 'Интерполяционный полином Лагранжа'")
-    print("t24 'Метод кубической сплайн-интерполяции'")
-    print("t25 'Операции в вычислительной линейной алгебре'")
-    print("t26 'Эффективная реализация умножения матриц'")
-    print("t27 'Алгоритм Штрассена и его сложность'")
-    print("t28 'Вычисление SVD'")
-    print("t29 'Собственные векторы и значения'")
-    print("t30 'Разложение по собственным векторам'")
-    print("t31 'Google PageRank — постановка и вычисление'")
+    print("t22 'Квадратичная интерполяция'")
+    print("t23 'Интерполяция сплайнами'")
+    print("t24 'Интерполяционный полином Лагранжа'")
+    print("t25 'Метод кубической сплайн-интерполяции'")
+    print("t26 'Основные операции в вычислительной линейной алгебре'")
+    print("t27 'Эффективная реализация алгоритмов вычисления произведения матриц'")
+    print("t28 'Алгоритм Штрассена, сложность метода Штрассена'")
+    print("t29 'Вычисление SVD'")
+    print("t30 'Собственные векторы, собственные значения'")
+    print("t31 'Разложение по собственным векторам'")
 
 def info7():
-    print("t32 'Характеристический многочлен и собственные значения'")
-    print("t33 'Степенной метод и его сходимость'")
-    print("t34 'Круги Гершгорина, теорема Гершгорина'")
-    print("t35 'Теорема Шура'")
-    print("t36 'Нормальные, эрмитовы, унитарные матрицы'")
-    print("t37 'Верхне-гессенбергова форма матрицы'")
-    print("t38 'Приведение к верхне-гессенберговой форме'")
-    print("t39 'Отношение Релея'")
-    print("t40 'Зазор между собственными значениями, алгоритмы со сдвигами'")
-    print("t41 'Отражения Хаусхолдера'")
+    print("t32 'Задача Google PageRank'")
+    print("t33 'Вычисление собственых значений с помощью характеристического многочлена'")
+    print("t34 'Особенности степенного метода. Скорость сходимости.'")
+    print("t35 'Круги Гершгорина, теорема Гершгорина.'")
+    print("t36 'Теорема Шура'")
+    print("t37 'Нормальные матрицы, унитарно диагонализуемые матрицы, унитарные матрицы, эрмитовы матрицы'")
+    print("t38 'Верхне-гессенбергова форма матрицы'")
+    print("t39 'Приведение произвольной матрицы к верхне-гессенберговой форме'")
+    print("t40 'Отношение Релея'")
+    print("t41 'Зазор между собственными значениями в матрице, алгоритмы со сдвигами.'")
 
 def info8():
-    print("t42 'Сходимость и сложность QR-алгоритма'")
-    print("t43 'Метод главных компонент, сингулярные значения'")
-    print("t44 'SVD — сингулярное разложение'")
-    print("t45 'Плотные и разреженные матрицы'")
-    print("t46 'Хранение разреженных матриц'")
+    print("t42 'Отражения Хаусхолдера'")
+    print("t43 'Сходимость и сложность QR алгоритма'")
+    print("t44 'Метод главных компонент и поиск сингулярных значений, прикладные аспекты'")
+    print("t45 'Сингулярное разложение (SVD)'")
+    print("t46 'Плотные и разреженные матрицы, способы хранения разреженных матриц'")
     print("t47 'ОДУ, численное дифференцирование, типы ОДУ'")
     print("t48 'Методы разностей: прямая, обратная, центральная'")
     print("t49 'Локальная и глобальная ошибка, правило Симпсона, ошибка округления'")
@@ -148,7 +148,7 @@ def info9():
     print("t59 'Амплитудный и частотный спектры'")
     print("t60 'Фильтрация сигналов'")
     print("t61 'Преобразование Фурье для анализа сезонности во временных рядах'")
-    print("t62 'Дополнительные аспекты обработки сигналов (Оценка сложности и сходимости)'")
+    print("t62 'Дополнительные аспекты обработки сигналов (по необходимости)'")
 
 
 
